/* Helpful fragments for BSD users:
   
Here are routines used in ATP which might not be available on BSD 
type systems. There may be other functions missing from your system 
which you need, however these should get you started. 

They are provided as a basis for those wishing to port ATP to  
other systems. They might require some tweaking for your specific
situation.      
   
If you are using GCC you can add a flag to the cflags list in the
makefile:
              -DBSD	 

If your compiler won't accept a "define" flag then explicitly
add the following def at the top of read.c : 
 
             #define BSD 1  

What's going on here is that there is an "#ifdef BSD" at the bottom
of read.c. If BSD is defined, then the file you are reading will
be included when read.c is compiled. But first review this module
which you are now looking at and comment out things which you might
not need, or you could add things here that you do need.

In other words, if you have a BSD flavor Unix, you are going to have
to muck around a little bit. When you get it right please send me
the patches so that I can include your efforts with credit in future
releases. Thanks!

*/	  

/* there are  3 "defines" below, comment out what you don't need */ 

/* use the following macro if you don't have memcpy() but do have bcopy() */
/* if you don't need this function, then comment it out!                  */

#define  memcpy(D,S,N)  bcopy((S),(D),(N))

#define MEMSET  1     /* comment this out if you already have memset(); */ 
#define STRSTR  1     /* comment this out if you already have strstr(); */

/* For those that do not have memset() */

#ifdef MEMSET		
char *memset(dst, chr, len)
char *dst;
register chr;
register len;
{
	char *d;
	for (d = dst; --len >= 0; *d++ = chr)
		;
	return dst;
}
#endif


/* For those that do not have strstr() */
/*	Find first occurence of str2 in str1 and return a pointer to it */

#ifdef	STRSTR	
char *strstr(str1, str2)
char *str1, *str2;
{
	register char *Sptr, *Tptr;
	int len = strlen(str1) -strlen(str2) + 1;

	if (*str2)
		for (; len > 0; len--, str1++) {
			if (*str1 != *str2)
				continue;

			for (Sptr = str1, Tptr = str2; *Tptr != '\0'; Sptr++, Tptr++)
				if (*Sptr != *Tptr)
					break;

			if (*Tptr == '\0')
				return str1;
		}

	return NULLS;
}
#endif

